@@ -15,11 +15,16 @@ import requests
 import webbrowser
 from getpass import getpass
 
-from .utils import join, NBOX_HOME_DIR, isthere, logger
+import nbox.utils as U
+from nbox.utils import join, isthere, logger
 
 # ------ AWS Auth ------ #
 
 class AWSClient:
+  """AWS Authentication class
+  
+  EXPERIMENTAL: This is not yet ready for use.
+  """
   @isthere("boto3", "botocore", soft = False)
   def __init__(self, aws_access_key_id: str, aws_secret_access_key: str, region_name: str):
     """Template for creating your own AWS authentication class.
@@ -58,6 +63,10 @@ class AWSClient:
 # ------ GCP Auth ------ #
 
 class GCPClient:
+  """GCP Authentication class
+  
+  EXPERIMENTAL: This is not yet ready for use.
+  """
   @isthere("google-cloud-sdk", "google-cloud-storage", soft = False)
   def __init__(self, project_id: str, credentials_file):
     """Template for creating your own authentication class.
@@ -96,6 +105,10 @@ class GCPClient:
 # ------ Azure Auth ------ #
 
 class AzureClient:
+  """Azure Authentication class
+  
+  EXPERIMENTAL: This is not yet ready for use.
+  """
   @isthere("azure-storage-blob", soft = False)
   def __init__(self):
     """
@@ -123,6 +136,10 @@ class AzureClient:
 # ------ OCI Auth ------ #
 
 class OCIClient:
+  """Oracle Cloud Infrastructure Authentication class
+  
+  EXPERIMENTAL: This is not yet ready for use.
+  """
   @isthere("oci", "oci-py", soft = False)
   def __init__(self, config_file):
     """
@@ -160,6 +177,10 @@ class OCIClient:
 # ------ Digital Ocean Auth ------ #
 
 class DOClient:
+  """Digital Ocean Authentication class
+  
+  EXPERIMENTAL: This is not yet ready for use.
+  """
   @isthere("doctl", soft = False)
   def __init__(self, config_file):
     """
@@ -188,29 +209,33 @@ class DOClient:
 
 class NBXClient:
   def __init__(self, nbx_url = "https://app.nimblebox.ai"):
-    """We try to find the values secrets file in the ``~/.nbx/secrets.json``, if not
-    found, we ask the user for the email and direct them to browser.
     """
-    os.makedirs(NBOX_HOME_DIR, exist_ok=True)
-    fp = join(NBOX_HOME_DIR, "secrets.json")
+    Single source for all the secrets file. Can persist across multiple processes.
+    """
+    os.makedirs(U.env.NBOX_HOME_DIR(), exist_ok=True)
+    self.fp = join(U.env.NBOX_HOME_DIR(), "secrets.json")
+
+    access_token = U.env.NBOX_USER_TOKEN("")
 
     # if this is the first time starting this then get things from the nbx-hq
-    if not os.path.exists(fp):
-      logger.info(f"Ensure that you put the email ID you have signed up with!")
-      _secrets_url = f"{nbx_url}/secrets"
-      logger.info(f"Opening: {_secrets_url}")
-      webbrowser.open(_secrets_url)
-      access_token = getpass("Access Token: ")
+    if not os.path.exists(self.fp):
+      if not access_token:
+        logger.info(f"Ensure that you put the email ID you have signed up with!")
+        _secrets_url = f"{nbx_url}/secrets"
+        logger.info(f"Opening: {_secrets_url}")
+        webbrowser.open(_secrets_url)
+        access_token = getpass("Access Token: ")
       
       # Once we have the access token, we can get the secrets
       r = requests.get(f"{nbx_url}/api/v1/user/account_details", headers={"Authorization": f"Bearer {access_token}"})
+      r.raise_for_status()
       try:
-        r.raise_for_status()
         username = r.json()["data"]["username"]
         email = r.json()["data"]["email"]
-      except:
-        username = ""
-        email = ""
+      except Exception as e:
+        logger.error(f"Could not get the username and email from the response")
+        logger.error(f"This should not have happened, please contact NimbleBox support.")
+        raise e
 
       # create the objects
       self.secrets = {
@@ -219,11 +244,11 @@ class NBXClient:
         "nbx_url": nbx_url,
         "username": username
       }
-      with open(fp, "w") as f:
+      with open(self.fp, "w") as f:
         f.write(repr(self))
       logger.info("Successfully created secrets!")
     else:
-      with open(fp, "r") as f:
+      with open(self.fp, "r") as f:
         self.secrets = json.load(f)
       logger.debug("Successfully loaded secrets!")
 
@@ -231,17 +256,21 @@ class NBXClient:
     return json.dumps(self.secrets, indent=2)
 
   def get(self, item, default=None):
+    # with open(self.fp, "r") as f:
+    #   self.secrets = json.load(f)
     return self.secrets.get(item, default)
 
   def put(self, item, value, persist: bool = False):
     self.secrets[item] = value
     if persist:
-      with open(join(NBOX_HOME_DIR, "secrets.json"), "w") as f:
+      with open(self.fp, "w") as f:
         f.write(repr(self))
 
 
 def init_secret():
   # add any logic here for creating secrets
-  return NBXClient()
+  if not U.env.NBOX_NO_AUTH(False):
+    return NBXClient()
+  return None
 
 secret = init_secret()
